#!/bin/sh 
#
# Usage: change [-v] device rootHandle parenthandle classHandle newlineRate burst
#
# Reallocate the specified device with new capacity
#
# Note: this script is CBQ protocol dependent
#       assumes that the line speed is 100Mbit
#
# Author:  JF Huard
# Version: $ $
# $Id: change.cgi,v 1.1 2001/04/17 22:25:51 marcs Exp $
#

TC=TC_DIR/tc
AWK=/bin/awk
GREP="/bin/grep -w"
ECHO=/bin/echo

echo Content-type: text/plain
echo

usage() {
    echo "usage: $0 [-v] -dev device -rhdl rootHandle "
    echo "               -phdl parentHandle -chdl classHandle "
    echo "               -rate classRate -burst burst"
    echo "       unit for rate in kbit/s"
    echo ""
}

case $1 in
-hv|-h|-vh) usage ; exit 1 ;;
-v*) VERBOSE=1 ; echo Verbose ON ; shift  ;;
*)  VERBOSE=0 ;;
esac

############ parse command line parameters ############

case $# in
0) echo ERROR ; usage ; exit 1;;
12)
	while [ $# -gt 0 ] 
	    do
		case $1 in
		    -dev)  DEVICE=$2       ;;
		    -rhdl) ROOTHANDLE=$2   ;; #root handle
		    -phdl) PARHANDLE=$2    ;; #Parent Handle
                    -chdl) CLSHANDLE=$2    ;; #class handle
		    -rate) CLSRATE=$2      ;; #class rate
		    -burst) BURST=$2       ;; #burst
                    *) echo ERROR wrong argument $1 ; exit 1;;
		esac
		shift 2
	    done ;;

*) echo ERROR ; usage ; exit 1;;
esac

RHDL="$ROOTHANDLE":"$PARHANDLE"
CHDL="$ROOTHANDLE":"$CLSHANDLE"

if [ $VERBOSE -eq 1 ]; then 
    echo interface:     $DEVICE
    echo root handle:   $ROOTHANDLE
    echo parent handle: $RHDL
    echo class handle:  $CHDL
    echo class rate:    $CLSRATE
    echo burst:         $BURST
    echo 
fi


#tc qdisc replace dev eth0 parent 1:31 tbf rate 3333Kbit burst 40K limit 40K
 
RET=`$TC qdisc replace dev $DEVICE parent $CHDL tbf rate "$CLSRATE"Kbit burst "$BURST"K limit "$BURST"K 2>&1`

if [ -n "$RET" ] ; then
    echo ERROR $DEVICE cannot change qdisc rate
    exit 1
fi

#tc class replace dev eth0 parent 1:1 classid 1:31 cbq rate 3333Kbit

RET=`$TC class replace dev $DEVICE parent $RHDL classid $CHDL cbq rate "$CLSRATE"Kbit 2>&1`

if [ -n "$RET" ] ; then
    echo ERROR $DEVICE cannot change class rate
    exit 1
fi

echo SUCCESS $DEVICE $ROOTHANDLE $PARHANDLE $CLSHANDLE $CLSRATE $BURST

exit


