#!/bin/sh 
#
# Usage: setcap [-v] device capacity seller_ handle
#
# Set the capacity the specified device with
# queueing discipline CBQ.  
#
# Note: this script is CBQ protocol dependent
#
# Author:  JF Huard
# Version: $Revision: 1.4 $, $Date: 2001/04/17 22:24:56 $
# $Id: setcap2.cgi,v 1.4 2001/04/17 22:24:56 marcs Exp $

TC=TC_DIR/tc
AWK=/bin/awk
GREP="/bin/grep -w"
ECHO=/bin/echo

usage() {
    echo "usage: $0 [-hv] -dev device -cap capacity -shdl sellerHandle" 
    echo ""
}

echo Content-type: text/plain
echo

case $1 in
-hv|-h|-vh) usage ; exit 1 ;;
-v*) VERBOSE=1 ; echo Verbose ON ; shift  ;;
*)  VERBOSE=0 ;;
esac

############ parse command line parameters ############

case $# in
0) echo ERROR ; usage ; exit 1;;
6) 
	while [ $# -gt 0 ] 
	    do
		case $1 in
		    -dev)  DEVICE=$2       ;;
		    -cap)  CAPACITY=$2     ;; #capacity
		    -shdl) SELLHDL=$2      ;; #Parent Handle
                    *) echo ERROR wrong argument $1 ; exit 1;;
		esac
		shift 2
	    done ;;
*) echo ERROR ; usage ; exit 1;;
esac

QDISC_RSP=`$TC qdisc show dev $DEVICE 2>&1`
NODEV=`$ECHO $QDISC_RSP | $GREP "Cannot find device"`
if [ -n "$NODEV" ]; then
    echo ERROR $DEVICE not found
    exit 1
else
    if [ -z "$QDISC_RSP" ] ; then
	echo ERROR $DEVICE not initialized
	exit 1
    fi
fi

ROOTLN=`$TC class show dev $DEVICE | $GREP root | $GREP cbq`

if [ -z "$ROOTLN" ] ; then
    echo ERROR $DEVICE CBQ root class not initialized
    exit 1
else
    ROOTRATE=`$ECHO $ROOTLN | $AWK '{ print $6 }'`
    ROOTHANDLE=`$ECHO $ROOTLN | $AWK '{ print $3 }'`
fi

CLSHANDLE=$ROOTHANDLE$SELLHDL
PARHANDLE=$ROOTHANDLE

if [ $VERBOSE -eq 1 ] ; then 
    echo interface rate: $ROOTRATE
    echo capacity  rate: $CAPACITY
    echo root   handle:  $ROOTHANDLE
    echo parent handle:  $PARHANDLE
    echo class  handle:  $CLSHANDLE
    echo
fi

RET=`$TC class replace dev $DEVICE parent $PARHANDLE \
          classid $CLSHANDLE cbq bandwidth $ROOTRATE \
          rate "$CAPACITY"kbit cell 8 weight 1Mbit \
          prio 8 maxburst 20 avpkt 1000 2>&1`

if [ -n "$RET" ] ; then
    echo ERROR $DEVICE cannot reset capacity for class
    exit 1
fi

echo SUCCESS $DEVICE $CAPACITY $SELLHDL

exit

#
# $Log: setcap2.cgi,v $
# Revision 1.4  2001/04/17 22:24:56  marcs
# added parse support for prefix of command line parameters
#
# Revision 1.3  2000/12/02 04:10:03  jfhuard
# typo and path for TC
#
# Revision 1.2  2000/12/02 04:09:09  jfhuard
# *** empty log message ***
#
# Revision 1.1  2000/12/02 04:06:08  jfhuard
# new API
# not backward compatible
#
#