#!/bin/sh 
#
# Usage: unalloc [-v] device rootHandle parentHandle classHandle
#
# Remove a specific queue/class set using the alloc script.
#
# Note: this script is CBQ protocol dependent
#
# Author:  JF Huard
# Version: $Revision: 1.5 $, $Date: 2001/05/11 14:47:55 $

TC=TC_DIR/tc
AWK=/bin/awk
GREP="/bin/grep -w"
ECHO=/bin/echo
MON=CGI_DIR/mon.sh

echo Content-type: text/plain
echo

usage() {
    echo "usage: $0 [-v] -dev device -rhdl rootHandle "
    echo "               -phdl parentHandle -chdl classHandle "
    echo ""
}

case $1 in
-hv|-h|-vh) usage ; exit 1 ;;
-v*) VERBOSE=1 ; echo Verbose ON ; shift  ;;
*)  VERBOSE=0 ;;
esac

############ parse command line parameters ############

case $# in
0) echo ERROR ; usage ; exit 1;;
8)
	while [ $# -gt 0 ] 
	    do
		case $1 in
		    -dev)  DEVICE=$2       ;;
		    -rhdl) ROOTHANDLE=$2   ;; #root handle
		    -phdl) PARHANDLE=$2    ;; #Parent Handle
                    -chdl) CLSHANDLE=$2    ;; #class handle
                    *) echo ERROR wrong argument $1 ; exit 1;;
		esac
		shift 2
	    done ;;

*) echo ERROR ; usage ; exit 1;;
esac

PHDL="$ROOTHANDLE":"$PARHANDLE"
CHDL="$ROOTHANDLE":"$CLSHANDLE"

if [ $VERBOSE -eq 1 ] ; then 
    echo interface     : $DEVICE
    echo root handle   : $ROOTHANDLE
    echo parent handle : $PHDL
    echo class handle  : $CHDL
fi

if [ -s $MON ] ; then
   RET=`/bin/sh $MON $DEVICE $ROOTHANDLE $PARHANDLE $CLSHANDLE`

   if [ -n "$RET" ] ; then
      echo ERROR monitoring: $RET
      exit 1
   fi
fi

RET=`$TC qdisc del dev $DEVICE parent $CHDL tbf 2>&1`

if [ -n "$RET" ] ; then
    echo ERROR $DEVICE cannot remove old tbf queue
    exit 1
fi

FHDL=`$TC filter ls dev $DEVICE | grep $CHDL | awk '{print $10}'`
PRIO=`$TC filter ls dev $DEVICE | grep $CHDL | awk '{print $7}'`

RET=`$TC filter del dev $DEVICE  protocol ip prio $PRIO parent $ROOTHANDLE: handle $FHDL u32 2>&1` 

if [ -n "$RET" ] ; then
    echo ERROR $DEVICE cannot delete filter
    exit 1
fi

RET=`$TC class del dev $DEVICE parent $PHDL classid $CHDL 2>&1`

if [ -n "$RET" ] ; then
    echo ERROR $DEVICE cannot delete class
    exit 1
fi

echo
echo SUCCESS $DEVICE $ROOTHANDLE $PARHANDLE $CLSHANDLE

exit